function DSSP(sourcefilepath, savefilepath)
%
% Extracting DSSP information from its web-download file.
% 
% Input:
%       sourcefilepath - the path of the source file or a variable
%       savefilepath   - the path the dssp file saved to
%
% Copyright Chen Peng NTU
% $Revision: 1.0 $   $Date: 2009/07/16 17:00:00 $

%% Achieve protein names from a variable or file
if exist('sourcefilepath', 'var')
    pdb_name = sourcefilepath;
elseif exist('sourcefilepath', 'file') % is a file that stored the required protein names
    if isdir(sourcefilepath)
        dir_file = dir('sourcefilepath');
        num_file = length(dir_file);
        for i = 3 : num_file
            pdb_name(i-2,1) = {dir_file(i,1).name};
        end
    else
        fid = fopen(sourcefilepath, 'r');
        num_column = 0;
        while 1
            tline = fgetl(fid);
            if ~ischar(tline),   break,   end
            if length(tline) >= 4
                num_column = num_column + 1;
                pdb_name(num_column,1) = {tline};
            end
        end
        fclose(fid);
    end
end

%% Extracting DSSP file from website and saved the parsing results to a
%% destination.
for i = 1 : size(pdb_name,1)  % obtain DSSP
    pdb = pdb_name{i,1}(1 : 4);
    disp([num2str(i) pdb]);
    url = ['http://mrs.cmbi.ru.nl/mrs-web/plain.do?db=dssp&id=' pdb];
    urlwrite(url, 'temp.txt');
    fid=fopen('temp.txt');
    num_R = 0; Infor = 'F'; tline = 1;
    while 1
        tline = fgetl(fid);
        if tline == -1
            break;
        end
        
        if length(tline) > 15
            if tline(3 : 12) == '#  RESIDUE'
                Infor = 'T';
            end
            if tline(1 : 11) == '</pre><div>'
                Infor = 'F';
            end
            if Infor == 'T' && ~strcmp(tline(3 : 12), '#  RESIDUE')
                if strfind(tline, '&lt;');
                    pos_l = strfind(tline, '&lt;');
                    for j = length(pos_l) : -1 : 1
                        tline(pos_l(j) + 1 : pos_l(j) + 3) = '';
                        tline(pos_l(j)) = '<';
                    end
                end
                if strfind(tline, '&gt;');
                    pos_g = strfind(tline, '&gt;');
                    for j = length(pos_g) : -1 : 1
                        tline(pos_g(j) + 1 : pos_g(j) + 3) = '';
                        tline(pos_g(j)) = '>';
                    end
                end

                num_R = num_R + 1;
                profile(num_R, 1)  = {tline(1 : 6)};        % #
                profile(num_R, 2)  = {tline(7 : 12)};       % RESIDUE
                profile(num_R, 3)  = {tline(13 : 15)};      % AA
                profile(num_R, 4)  = {tline(16 : 25)};      % STRUCTURE
                profile(num_R, 5)  = {tline(26 : 29)};      % BP1
                profile(num_R, 6)  = {tline(30 : 34)};      % BP2
                profile(num_R, 7)  = {tline(35 : 39)};      % ACC
                profile(num_R, 8)  = {tline(40 : 51)};      % N-H-->O
                profile(num_R, 9)  = {tline(52 : 62)};      % O-->H-N
                profile(num_R, 10) = {tline(63 : 73)};      % N-H-->O
                profile(num_R, 11) = {tline(74 : 84)};      % O-->H-N
                profile(num_R, 12) = {tline(85 : 91)};      % TCO
                profile(num_R, 13) = {tline(92 : 97)};      % KAPPA
                profile(num_R, 14) = {tline(98 : 103)};     % ALPHA
                profile(num_R, 15) = {tline(104 : 109)};    % PHI
                profile(num_R, 16) = {tline(110 : 115)};    % PSI
                profile(num_R, 17) = {tline(116 : 122)};    % X-CA
                profile(num_R, 18) = {tline(123 : 129)};    % Y-CA
                profile(num_R, 19) = {tline(130 : 136)};    % Z-CA
            end
        end       
    end
    fclose(fid);

    chains = 'F';
    if exist('profile', 'var')
        for j = length(profile(:, 1)) - 1 : -1 : 1
            if strfind(char(profile(j, 2)), '      ') == 1 
                pre = char(profile(j + 1, 2));
                nex = char(profile(j - 1, 2));
                if strcmp(pre(6 : 6), nex(6 : 6))  % A - A
                    profile(j, :) = [];
                else  % seperation of two chains
                    dssp_profile.(genvarname([pre(6)])) =...
                        profile(j + 1 : length(profile(:, 1)), :);
                    profile(j : length(profile(:, 1)), :) = [];
                    chains = 'T';
                end
            end
        end
        first = char(profile(2, 2));
        file_name = [savefilepath, lower(pdb), '.mat'];

        chain = char(profile(2, 2));
        if regexp(chain(6), '[A-Z]|[1-9]') >= 1 & chains == 'T'  % including several chains
                    dssp_profile.(genvarname(first(6))) =...
                        profile(j : length(profile(:, 1)), :);
    %         clear profile
        else  % only a single chain
            dssp_profile = profile;
        end

        save(file_name, 'dssp_profile');
        clear cell_str tline dssp_profile profile
    else
        pdb = [pdb '_error_' {i}];
    end
end