function HSSP(sourcefilepath, savefilepath)
%
% Extracting HSSP information from its web-download file.
% 
% Input:
%       sourcefilepath - the path of the source file or a variable
%       savefilepath   - the path the dssp file saved to
%
% Copyright Chen Peng NTU
% $Revision: 1.0 $   $Date: 2009/07/16 17:40:00 $

%% Achieve protein names from a directory or file
if exist(sourcefilepath, 'var')
    pdb_name = sourcefilepath;
elseif exist(sourcefilepath, 'file') % is a file that stored the required protein names
    if isdir(sourcefilepath)
        dir_file = dir(sourcefilepath);
        num_file = length(dir_file);
        for i = 3 : num_file
            pdb_name(i-2,1) = {dir_file(i,1).name};
        end
    else
        fid = fopen(sourcefilepath, 'r');
        num_column = 0;
        while 1
            tline = fgetl(fid);
            if ~ischar(tline),   break,   end
            if length(tline) >= 4
                num_column = num_column + 1;
                pdb_name(num_column,1) = {tline};
            end
        end
        fclose(fid);
    end
end
assignin('base', 'pdb_name', pdb_name);
%% Extracting HSSP file from website and saved the parsing results to a
%% destination.
for i = 1 : size(pdb_name,1)  % obtain HSSP
    pdb = pdb_name{i,1}(1 : 4);
    disp([num2str(i) ' ' pdb]);
    url = ['http://mrs.cmbi.ru.nl/mrs-web/plain.do?db=hssp&id=' pdb];
    urlwrite(url, 'temp.txt');
    fid=fopen('temp.txt');
    num_R = 0; Infor = 'F'; tline = 1;
    while 1
        tline = fgetl(fid);
        if tline == -1
            break;
        end
        if length(tline) >= 17
            if strfind(tline(1 : 17), ' SeqNo PDBNo   V ') == 1
                Infor = 'T';
            end
            if (strfind(tline(1 : 11), '</pre><div>') == 1)
                Infor = 'F';
                break;
            end
            if (strfind(tline(1 : 17), '## INSERTION LIST') ==1)
                Infor = 'F';
                break;
            end

            if Infor == 'T' && ~strcmp(tline(1 : 17), ' SeqNo PDBNo   V ')
                num_R = num_R + 1;
                profile(num_R, 1)  = {tline(1 : 6)};      % SeqNo
                profile(num_R, 2)  = {tline(7 : 12)};     % PDBNo
                profile(num_R, 3)  = {tline(13 : 16)};    % V
                profile(num_R, 4)  = {tline(17 : 20)};    % L
                profile(num_R, 5)  = {tline(21 : 24)};    % I
                profile(num_R, 6)  = {tline(25 : 28)};    % M
                profile(num_R, 7)  = {tline(29 : 32)};    % F
                profile(num_R, 8)  = {tline(33 : 36)};    % W
                profile(num_R, 9)  = {tline(37 : 40)};    % Y
                profile(num_R, 10) = {tline(41 : 44)};    % G
                profile(num_R, 11) = {tline(45 : 48)};    % A
                profile(num_R, 12) = {tline(49 : 52)};    % P
                profile(num_R, 13) = {tline(53 : 56)};    % S
                profile(num_R, 14) = {tline(57 : 60)};    % T
                profile(num_R, 15) = {tline(61 : 64)};    % C
                profile(num_R, 16) = {tline(65 : 68)};    % H
                profile(num_R, 17) = {tline(69 : 72)};    % R
                profile(num_R, 18) = {tline(73 : 76)};    % K
                profile(num_R, 19) = {tline(77 : 80)};    % Q
                profile(num_R, 20) = {tline(81 : 84)};    % E
                profile(num_R, 21) = {tline(85 : 88)};    % M
                profile(num_R, 22) = {tline(89 : 92)};    % D
                profile(num_R, 23) = {tline(93 : 98)};    % NOCC
                profile(num_R, 24) = {tline(99 : 103)};   % NDEL 
                profile(num_R, 25) = {tline(104 : 108)};  % NINS 
                profile(num_R, 26) = {tline(109 : 116)};  % ENTROPY 
                profile(num_R, 27) = {tline(117 : 123)};  % RELENT 
                profile(num_R, 28) = {tline(124 : 129)};  % WEIGHT
                if length(tline) == 130
                    profile(num_R, 28)  = {tline(124 : 130)};      % SeqNo
                end
            end
        end
        clear tline
    end
    fclose(fid);
    
    chains = 'F';
    if exist('profile', 'var')
        for j = length(profile(:, 1)) - 1 : -1 : 1
            if strfind(char(profile(j, 2)), '      ') == 1 
                pre = char(profile(j + 1, 2));
                nex = char(profile(j - 1, 2));
                if strcmp(pre(6 : 6), nex(6 : 6))  % A - A
                    profile(j, :) = [];
                else  % seperation of two chains
                    hssp_profile.(genvarname([pre(6)])) =...
                        profile(j + 1 : length(profile(:, 1)), :);
                    profile(j : length(profile(:, 1)), :) = [];
                    chains = 'T';
                end
            end
        end
        first = char(profile(2, 2));
        file_name = [savefilepath, lower(pdb), '.mat'];

        chain = char(profile(2, 2));
        if regexp(chain(6), '[A-Z]|[1-9]') >= 1 & chains == 'T'  % including several chains
                    hssp_profile.(genvarname(first(6))) =...
                        profile(j : length(profile(:, 1)), :);
    %         clear profile
        else  % only a single chain
            hssp_profile = profile;
        end

        save(file_name, 'hssp_profile');
        clear cell_str tline hssp_profile profile
    else
        pdb = [pdb '_error_' {i}];
    end
end
