function Interface(savefilepath)
%
% Find out surface residues and interface residues in terms of the
% calculation of solvent accessible surface area.
% 
%
% Copyright Chen Peng NTU
% $Revision: 1.0 $   $Date: 2009/07/22 11:30:00 $

%% Detect interface residues using PSAIA program which downloaded from
%% http://complex.zesoi.fer.hr/tools/PSAIA.html
% Interface results detected by PSAIA program are saved in directory "InterfaceTbl\"
dir_file = dir('InterfaceTbl\');
% savefilepath = 'Interface\';
num_file = length(dir_file);
for i = 3 : num_file
    fid = fopen(['InterfaceTbl\' dir_file(i,1).name], 'r');
    pdb = dir_file(i,1).name(1:4);
    disp([num2str(i-2) pdb]);
    preChain = 'XX';
    NoSeq = 0;
    while 1
        tline = fgetl(fid);
        if ~ischar(tline),   break,   end
        if length(tline) >= 20 && strcmp(tline(2:3), '  ')
            curChain = tline(1:1);
            if strcmp(preChain, curChain) % identify protein chains
                NoSeq = NoSeq + 1;
                preChain = curChain;
            else
                NoSeq = 1;
                preChain = curChain;
            end
            resStatus.(genvarname(curChain))(NoSeq,1) = {strtrim(tline(3:7))}; % residue sequence
            resStatus.(genvarname(curChain))(NoSeq,2) = {strtrim(tline(10:12))}; % residue name
            resStatus.(genvarname(curChain))(NoSeq,3) = {strtrim(tline(15:15))}; % binding status of the residue
        end
    end
    fclose(fid);
    file_name = [savefilepath, lower(pdb), '.mat'];
    save(file_name, 'resStatus');
    clear resStatus tline curChain preChain NoSeq
end

%% Extract ASA information before and after complexation
% ASA results detected by PSAIA program are saved in directory "StructureUnboundTbl\"
% ASA information before complexation is saved into directory "StructureUnbound\"
dir_file = dir('StructureUnboundTbl\');
savefilepath = 'StructureUnbound\';
num_file = length(dir_file);
for f = 3 : num_file
    fid = fopen(['StructureUnboundTbl\' dir_file(f,1).name], 'r');
    pdb = dir_file(f,1).name(1:4);
    disp([num2str(f-2) ' ' pdb]);
    initial = 'F';
    while 1
        tline = fgetl(fid);
        if ~ischar(tline),   break,   end
        if initial == 'T'
            [start_idx, end_idx] = regexp(tline, '[ ]+');
            if chain == strtrim(tline(end_idx(1):start_idx(2)))
                num = num + 1;
            else
                num = 1;
            end
            for i = 2 : length(start_idx)-1
                structunboundStatus.(genvarname(strtrim(tline(end_idx(1)+1:start_idx(2)-1))))(num,i-1) = {strtrim(tline(end_idx(i)+1:start_idx(i+1)-1))};
            end
            chain = strtrim(tline(end_idx(1)+1:start_idx(2)-1));
        end
        if length(tline) >= 300 && strcmp(tline(1:11), '  chain id|')
            initial = 'T';
            chain = '';
        end
    end
    file_name = [savefilepath, lower(pdb), '.mat'];
    save(file_name, 'structunboundStatus');
    clear structunboundStatus tline chain start_idx end_idx
    fclose(fid);
end

% ASA results detected by PSAIA program are saved in directory "StructureBoundTbl\"
% ASA information after complexation is saved into directory "StructureBound\"
dir_file = dir('StructureBoundTbl');
savefilepath = 'StructureBound\';
num_file = length(dir_file);
for f = 3 : num_file
    fid = fopen(['StructureBoundTbl\' dir_file(f,1).name], 'r');
    pdb = dir_file(f,1).name(1:4);
    disp([num2str(f-2) ' ' pdb]);
    initial = 'F';
    while 1
        tline = fgetl(fid);
        if ~ischar(tline),   break,   end
        if initial == 'T'
            [start_idx, end_idx] = regexp(tline, '[ ]+');
            if chain == strtrim(tline(end_idx(1):start_idx(2)))
                num = num + 1;
            else
                num = 1;
            end
            for i = 2 : length(start_idx)-1
                structboundStatus.(genvarname(strtrim(tline(end_idx(1)+1:start_idx(2)-1))))(num,i-1) = {strtrim(tline(end_idx(i)+1:start_idx(i+1)-1))};
            end
            chain = strtrim(tline(end_idx(1)+1:start_idx(2)-1));
        end
        if length(tline) >= 300 && strcmp(tline(1:11), '  chain id|')
            initial = 'T';
            chain = '';
        end
    end
    file_name = [savefilepath, lower(pdb), '.mat'];
    save(file_name, 'structboundStatus');
    clear structboundStatus tline chain start_idx end_idx
    fclose(fid);
end

