function [Sen, Spec, Acc, CC, Precision, Fmeasure] = Performance(True, Prediction)
%
% Input:
%       True          - true target, 1*L vector
%       Prediction    - prediction target, 1*L vector
%
% Output:
%       Sen  - sensitivity, Sen=TP/(FN+TP)
%       Spec - specificity, Spec=TN/(FP+TN)
%       Acc  - overall accuracy, Acc=(TN+TP)/(TN+FP+FN+TP)
%       CC   - correlation coefficient, CC=(TP*TN-FP*FN)/(sqrt((TP+FN)(TP+FP)(TN+FP)(TN+FN)))
%       Precision - Prec = TP/(TP+FP)
%       Fmeasure  - measure between precision and sensitivity
% 
%
% Copyright Chen Peng NTU
% $Revision: 1.0 $   $Date: 2009/09/30 13:32:00 $

TP = length(find(True(1,Prediction==1)==1));
FP = length(find(True(1,Prediction==1)==0));
TN = length(find(True(1,Prediction==0)==0));
FN = length(find(True(1,Prediction==0)==1));

if (FN+TP) == 0
    Sen = 0;
else
    Sen = TP/(FN+TP); % same as "Recall"
end
if (FP+TN) == 0
    Spec = 0;
else
    Spec = TN/(FP+TN);
end
Acc = (TN+TP)/(TN+FP+FN+TP);
if (TP+FN)*(TP+FP)*(TN+FP)*(TN+FN) == 0
    CC = 0;
else
    CC = (TP*TN-FP*FN)/(sqrt((TP+FN)*(TP+FP)*(TN+FP)*(TN+FN)));
end
if (TP+FP) == 0
    Precision = 0;
else
    Precision = TP/(TP+FP);
end
if (Precision+Sen) == 0
    Fmeasure = 0;
else
    Fmeasure = 2*(Precision*Sen)/(Precision+Sen);
end
