% function Predictor()
%
% Function to identify protein-protein binding sites using SVM package of
% osu_svm3.00. It divides dataset into a training subset and a test subset.
% Users can rewrite the program to implement their own tasks.
% 
% The version just shows the a part of cross-validation. Users can continue
% the process by changing the training set and test set.
%
% Copyright Chen Peng NTU
% $Revision: 1.0 $   $Date: 2009/09/30 11:00:00 $


%% A two-stage classifier with different dataset and SOM
[cefv, aa] = cef();
neighbor = 9;
encoding = 1;
dir_file = dir('HSSP\');
num_file = length(dir_file);
descriptor = aa.Kyte';
Test = [];
T_test = [];
for i = 601 : num_file
%     disp([num2str(i) '  ' dir_file(i,1).name(1:4)]);
    load(['HSSP\' dir_file(i,1).name]);
    load(['Interface\' dir_file(i,1).name]);
    [Test1, T_test1] = InputTarget(hssp_profile, resStatus, neighbor, descriptor, encoding);
    Test = [Test; Test1];
    T_test = [T_test; T_test1];
end
Test0 = Scale(Test', 0 ,1)';

Train = [];
T_train = [];
for i = 3 : 600
    load(['HSSP\' dir_file(i,1).name]);
    load(['Interface\' dir_file(i,1).name]);
    [Train1, T_train1] = InputTarget(hssp_profile, resStatus, neighbor, descriptor, encoding);
    Train = [Train; Train1];
    T_train = [T_train; T_train1];
end
Train0 = Scale(Train', 0 ,1)';

%% construct predictors
K1 = 2; K0 = 5; % the number of subset for postive and negative samples
pos1 = find(T_train==1);
pos0 = find(T_train==0);
if length(pos1)/K1 > length(pos0)/K0
    sizeSubset = floor(length(pos0)/K0);
else
    sizeSubset = floor(length(pos1)/K1);
end
indices1 = crossvalind('Kfold', pos1(1:sizeSubset*K1), K1);
indices0 = crossvalind('Kfold', pos0(1:sizeSubset*K0), K0);

for k =  1 : K1 % loop for indices1
    for j = 1 : K0 % loop for indices0
        kfold1 = pos1(indices1==k);
        kfold0 = pos0(indices0==j);
        pos1 = find(T_train==1);
        No_train = [kfold1; kfold0];
        Gamma = 5;
        C = 1;
        % train the predictor on the training subset
        cd('PrePPI');
        [AlphaY, SVs, Bias, Parameters, nSV, nLabel] = RbfSVC(double(Train0(No_train,:)'), double(T_train(No_train,:)'), Gamma, C);      
        TrainSVC.(genvarname(['K1_' num2str(k) '_K0_' num2str(j)])) = {AlphaY, SVs, Bias, Parameters, nSV, nLabel, kfold1, kfold0};
        cd ..;
        
        % test the predictor on the test subset. Users can train for individual complex
        cd('PrePPI');
        [ClassRate, DecisionValue, Ns, ConfMatrix, PreLabels]= SVMTest(double(Test0'), T_test', AlphaY, SVs, Bias,Parameters, nSV, nLabel);
        cd ..;

        Perform0((k-1)*K0+j,1) = {DecisionValue};
        Perform0((k-1)*K0+j,2) = {PreLabels};
        Perform0((k-1)*K0+j,3) = {T_test};

        Decision = sort(DecisionValue);
        PreLabels(1,DecisionValue>Decision(ceil(length(Decision)*0.9)))=1;
        PreLabels(1,DecisionValue<=Decision(ceil(length(Decision)*0.9)))=0;
        [Sen, Spec, Acc, CC, Precision, Fmeasure] = Performance(T_test', PreLabels);
        Perform0((k-1)*K0+j,4) = {[Sen, Spec, Acc, CC, Precision, Fmeasure]};
        fprintf(1, 'sub:%-4d Sen=%2.2f Spec=%2.2f Ac=%2.2f CC=%2.2f Precision=%2.2f Fmeasure=%2.2f\n', (k-1)*18+j, Sen*100, Spec*100, Acc*100, CC*100, Precision*100, Fmeasure*100);
    end
    clear RbfSVC
end

%% combine the ten-SVMs and compute the performance of SVMs ensemble
num_j = 0;
for j = 0.001 : 0.01 : 1 
    num_j = num_j + 1;
    PreLabels0 = zeros(1,length(Perform0{1,2}));
    for i = 1 : size(Perform0,1)
        DecisionValue1 = Perform0{i,1};
        PreLabels1 = Perform0{i,2};
        Decision = sort(DecisionValue1);
        PreLabels=PreLabels1;
        PreLabels(1,DecisionValue1>Decision(ceil(length(Decision)*j)))=1;
        PreLabels(1,DecisionValue1<=Decision(ceil(length(Decision)*j)))=0;
        PreLabels0 = PreLabels0 + PreLabels;
    end    
    for i = 1 : size(Perform0,1)
        PreLabels=PreLabels0;
        PreLabels(1,PreLabels0<i)=0;
        PreLabels(1,PreLabels0>=i)=1;
        [Sen, Spec, Acc, CC, Precision, Fmeasure] = Performance(Perform0{1,3}', PreLabels);
        roc(i,1:6,num_j) = [Sen, Spec, Acc, CC, Precision, Fmeasure];
    end
end

% plot the ROC performance
colorstr = 'rgbcmykw';
for i = 1 : size(Perform0,1)
    roc1(1,1:size(roc,3)) = roc(i,1,:);
    roc2(1,1:size(roc,3)) = roc(i,5,:);
    plot(roc1,roc2, colorstr(i));
    hold on;
end
hold off;

